ExSplit

Struct ExSplit 

pub struct ExSplit<'s, 'w> { /* private fields */ }
Manual extender for GString::split_ex.

Implementations

Source

impl<'s, 'w> ExSplit<'s, 'w>

pub fn disallow_empty(self) -> Self

After calling this method, empty strings between adjacent delimiters are excluded from the array.

pub fn maxsplit(self, number_of_splits: usize) -> Self

Limit number of splits (forward mode).

If maxsplit is greater than 0, the number of splits may not exceed maxsplit. By default, the entire string is split.

Note that number_of_splits refers to the number of times a split occurs, which is the resulting element count minus one.

pub fn maxsplit_r(self, number_of_splits: usize) -> Self

Limit number of splits (reverse mode).

If maxsplit is greater than 0, the number of splits may not exceed maxsplit. By default, the entire string is split.

Note that number_of_splits refers to the number of times a split occurs, which is the resulting element count minus one.

pub fn done(self) -> PackedStringArray

Does the actual work. Must be called to finalize split operation.