pub struct ExSplit<'s, 'w> { /* private fields */ }Expand description
Manual extender for StringName::split_ex.
Implementations
Sourceimpl<'s, 'w> ExSplit<'s, 'w>
impl<'s, 'w> ExSplit<'s, 'w>
Sourcepub fn disallow_empty(self) -> Self
pub fn disallow_empty(self) -> Self
After calling this method, empty strings between adjacent delimiters are excluded from the array.
Sourcepub fn maxsplit(self, number_of_splits: usize) -> Self
pub fn maxsplit(self, number_of_splits: usize) -> Self
Limit number of splits (forward mode).
If maxsplit is greater than 0, the number of splits may not exceed maxsplit. By default, the entire string is split.
Note that number_of_splits refers to the number of times a split occurs, which is the resulting element count minus one.
Sourcepub fn maxsplit_r(self, number_of_splits: usize) -> Self
pub fn maxsplit_r(self, number_of_splits: usize) -> Self
Limit number of splits (reverse mode).
If maxsplit is greater than 0, the number of splits may not exceed maxsplit. By default, the entire string is split.
Note that number_of_splits refers to the number of times a split occurs, which is the resulting element count minus one.