pub struct Engine { /* private fields */ }Expand description
Godot class Engine.
Inherits Object.
Related symbols:
See also Godot docs for Engine.
Singleton
This class is a singleton. You can get the one instance using Singleton::singleton().
Final class
This class is final, meaning you cannot inherit from it, and it comes without I* interface trait. It is still possible that other Godot classes inherit from it, but that is limited to the engine itself.
Godot docs
The Engine singleton allows you to query and modify the project’s run-time parameters, such as frames per second, time scale, and others. It also stores information about the current build of Godot, such as the current version.
Implementations
Sourceimpl Engine
impl Engine
pub fn set_physics_ticks_per_second(&mut self, physics_ticks_per_second: i32)
pub fn get_physics_ticks_per_second(&self) -> i32
pub fn set_max_physics_steps_per_frame(&mut self, max_physics_steps: i32)
pub fn get_max_physics_steps_per_frame(&self) -> i32
pub fn set_physics_jitter_fix(&mut self, physics_jitter_fix: f64)
pub fn get_physics_jitter_fix(&self) -> f64
Sourcepub fn get_physics_interpolation_fraction(&self) -> f64
pub fn get_physics_interpolation_fraction(&self) -> f64
Returns the fraction through the current physics tick we are at the time of rendering the frame. This can be used to implement fixed timestep interpolation.
pub fn set_max_fps(&mut self, max_fps: i32)
pub fn get_max_fps(&self) -> i32
pub fn set_time_scale(&mut self, time_scale: f64)
pub fn get_time_scale(&self) -> f64
Sourcepub fn get_frames_drawn(&self) -> i32
pub fn get_frames_drawn(&self) -> i32
Returns the total number of frames drawn since the engine started.
Note: On headless platforms, or if rendering is disabled with --disable-render-loop via command line, this method always returns 0. See also get_process_frames.
Sourcepub fn get_frames_per_second(&self) -> f64
pub fn get_frames_per_second(&self) -> f64
Returns the average frames rendered every second (FPS), also known as the framerate.
Sourcepub fn get_physics_frames(&self) -> u64
pub fn get_physics_frames(&self) -> u64
Returns the total number of frames passed since the engine started. This number is increased every physics frame. See also get_process_frames.
This method can be used to run expensive logic less often without relying on a Timer:
func _physics_process(_delta):
if Engine.get_physics_frames() % 2 == 0:
pass # Run expensive logic only once every 2 physics frames here.Sourcepub fn get_process_frames(&self) -> u64
pub fn get_process_frames(&self) -> u64
Returns the total number of frames passed since the engine started. This number is increased every process frame, regardless of whether the render loop is enabled. See also get_frames_drawn and get_physics_frames.
This method can be used to run expensive logic less often without relying on a Timer:
func _process(_delta):
if Engine.get_process_frames() % 5 == 0:
pass # Run expensive logic only once every 5 process (render) frames here.Sourcepub fn get_main_loop(&self) -> Option<Gd<MainLoop>>
pub fn get_main_loop(&self) -> Option<Gd<MainLoop>>
Sourcepub fn get_version_info(&self) -> VarDictionary
pub fn get_version_info(&self) -> VarDictionary
Returns the current engine version information as a [Dictionary][crate::builtin::Dictionary] containing the following entries:
-
major- Major version number as an int; -
minor- Minor version number as an int; -
patch- Patch version number as an int; -
hex- Full version encoded as a hexadecimal int with one byte (2 hex digits) per number (see example below); -
status- Status (such as “beta”, “rc1”, “rc2”, “stable”, etc.) as a String; -
build- Build name (e.g. “custom_build”) as a String; -
hash- Full Git commit hash as a String; -
timestamp- Holds the Git commit date UNIX timestamp in seconds as an int, or0if unavailable; -
string-major,minor,patch,status, andbuildin a single String.
The hex value is encoded as follows, from left to right: one byte for the major, one byte for the minor, one byte for the patch version. For example, “3.1.12” would be 0x03010C.
Note: The hex value is still an int internally, and printing it will give you its decimal representation, which is not particularly meaningful. Use hexadecimal literals for quick version comparisons from code:
if Engine.get_version_info().hex >= 0x040100:
pass # Do things specific to version 4.1 or later.
else:
pass # Do things specific to versions before 4.1.Returns the engine author information as a [Dictionary][crate::builtin::Dictionary], where each entry is an [Array][crate::builtin::Array] of strings with the names of notable contributors to the Godot Engine: lead_developers, founders, project_managers, and developers.
Sourcepub fn get_copyright_info(&self) -> Array<VarDictionary>
pub fn get_copyright_info(&self) -> Array<VarDictionary>
Returns an [Array][crate::builtin::Array] of dictionaries with copyright information for every component of Godot’s source code.
Every [Dictionary][crate::builtin::Dictionary] contains a name identifier, and a parts array of dictionaries. It describes the component in detail with the following entries:
Sourcepub fn get_donor_info(&self) -> VarDictionary
pub fn get_donor_info(&self) -> VarDictionary
Returns a [Dictionary][crate::builtin::Dictionary] of categorized donor names. Each entry is an [Array][crate::builtin::Array] of strings:
{platinum_sponsors, gold_sponsors, silver_sponsors, bronze_sponsors, mini_sponsors, gold_donors, silver_donors, bronze_donors}
Sourcepub fn get_license_info(&self) -> VarDictionary
pub fn get_license_info(&self) -> VarDictionary
Returns a [Dictionary][crate::builtin::Dictionary] of licenses used by Godot and included third party components. Each entry is a license name (such as “Expat”) and its associated text.
Sourcepub fn get_license_text(&self) -> GString
pub fn get_license_text(&self) -> GString
Returns the full Godot license text.
Sourcepub fn get_architecture_name(&self) -> GString
pub fn get_architecture_name(&self) -> GString
Returns the name of the CPU architecture the Godot binary was built for. Possible return values include "x86_64", "x86_32", "arm64", "arm32", "rv64", "ppc64", "loongarch64", "wasm64", and "wasm32".
To detect whether the current build is 64-bit, or the type of architecture, don’t use the architecture name. Instead, use has_feature to check for the "64" feature tag, or tags such as "x86" or "arm". See the Feature Tags documentation for more details.
Note: This method does not return the name of the system’s CPU architecture (like get_processor_name). For example, when running an x86_32 Godot binary on an x86_64 system, the returned value will still be "x86_32".
Sourcepub fn is_in_physics_frame(&self) -> bool
pub fn is_in_physics_frame(&self) -> bool
Returns true if the engine is inside the fixed physics process step of the main loop.
func _enter_tree():
# Depending on when the node is added to the tree,
# prints either "true" or "false".
print(Engine.is_in_physics_frame())
func _process(delta):
print(Engine.is_in_physics_frame()) # Prints false
func _physics_process(delta):
print(Engine.is_in_physics_frame()) # Prints trueSourcepub fn has_singleton(&self, name: impl AsArg<StringName>) -> bool
pub fn has_singleton(&self, name: impl AsArg<StringName>) -> bool
Returns true if a singleton with the given name exists in the global scope. See also get_singleton.
print(Engine.has_singleton("OS")) # Prints true
print(Engine.has_singleton("Engine")) # Prints true
print(Engine.has_singleton("AudioServer")) # Prints true
print(Engine.has_singleton("Unknown")) # Prints falseNote: Global singletons are not the same as autoloaded nodes, which are configurable in the project settings.
Sourcepub fn get_singleton(&self, name: impl AsArg<StringName>) -> Option<Gd<Object>>
pub fn get_singleton(&self, name: impl AsArg<StringName>) -> Option<Gd<Object>>
Returns the global singleton with the given name, or null if it does not exist. Often used for plugins. See also has_singleton and get_singleton_list.
Note: Global singletons are not the same as autoloaded nodes, which are configurable in the project settings.
Sourcepub fn register_singleton(
&mut self,
name: impl AsArg<StringName>,
instance: impl AsArg<Option<Gd<Object>>>,
)
pub fn register_singleton( &mut self, name: impl AsArg<StringName>, instance: impl AsArg<Option<Gd<Object>>>, )
Registers the given Object instance as a singleton, available globally under name. Useful for plugins.
Sourcepub fn unregister_singleton(&mut self, name: impl AsArg<StringName>)
pub fn unregister_singleton(&mut self, name: impl AsArg<StringName>)
Removes the singleton registered under name. The singleton object is not freed. Only works with user-defined singletons registered with register_singleton.
Sourcepub fn get_singleton_list(&self) -> PackedStringArray
pub fn get_singleton_list(&self) -> PackedStringArray
Returns a list of names of all available global singletons. See also get_singleton.
Sourcepub fn register_script_language(
&mut self,
language: impl AsArg<Option<Gd<ScriptLanguage>>>,
) -> Error
pub fn register_script_language( &mut self, language: impl AsArg<Option<Gd<ScriptLanguage>>>, ) -> Error
Registers a ScriptLanguage instance to be available with ScriptServer.
Returns:
-
Error::OKon success; -
Error::ERR_UNAVAILABLEifScriptServerhas reached the limit and cannot register any new language; -
Error::ERR_ALREADY_EXISTSifScriptServeralready contains a language with similar extension/name/type.
Sourcepub fn unregister_script_language(
&mut self,
language: impl AsArg<Option<Gd<ScriptLanguage>>>,
) -> Error
pub fn unregister_script_language( &mut self, language: impl AsArg<Option<Gd<ScriptLanguage>>>, ) -> Error
Unregisters the ScriptLanguage instance from ScriptServer.
Returns:
-
Error::OKon success; -
Error::ERR_DOES_NOT_EXISTif the language is not registered inScriptServer.
Sourcepub fn get_script_language_count(&self) -> i32
pub fn get_script_language_count(&self) -> i32
Returns the number of available script languages. Use with get_script_language.
Sourcepub fn get_script_language(&self, index: i32) -> Option<Gd<ScriptLanguage>>
pub fn get_script_language(&self, index: i32) -> Option<Gd<ScriptLanguage>>
Returns an instance of a ScriptLanguage with the given index.
Sourcepub fn is_editor_hint(&self) -> bool
pub fn is_editor_hint(&self) -> bool
Returns true if the script is currently running inside the editor, otherwise returns false. This is useful for @tool scripts to conditionally draw editor helpers, or prevent accidentally running “game” code that would affect the scene state while in the editor:
if Engine.is_editor_hint():
draw_gizmos()
else:
simulate_physics()See Running code in the editor in the documentation for more information.
Note: To detect whether the script is running on an editor build (such as when pressing F5), use has_feature with the "editor" argument instead. OS.has_feature("editor") evaluate to true both when the script is running in the editor and when running the project from the editor, but returns false when run from an exported project.
Sourcepub fn is_embedded_in_editor(&self) -> bool
pub fn is_embedded_in_editor(&self) -> bool
Returns true if the engine is running embedded in the editor. This is useful to prevent attempting to update window mode or window flags that are not supported when running the project embedded in the editor.
Sourcepub fn get_write_movie_path(&self) -> GString
pub fn get_write_movie_path(&self) -> GString
Returns the path to the MovieWriter’s output file, or an empty string if the engine wasn’t started in Movie Maker mode. The default path can be changed in [member ProjectSettings.editor/movie_writer/movie_file].
pub fn set_print_to_stdout(&mut self, enabled: bool)
pub fn is_printing_to_stdout(&self) -> bool
pub fn set_print_error_messages(&mut self, enabled: bool)
pub fn is_printing_error_messages(&self) -> bool
Methods from Deref<Target = Object>
pub fn get_script(&self) -> Option<Gd<Script>>
pub fn set_script(&mut self, script: impl AsArg<Option<Gd<Script>>>)
pub fn connect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, ) -> Error
pub fn connect_flags( &mut self, signal: impl AsArg<StringName>, callable: &Callable, flags: ConnectFlags, ) -> Error
Sourcepub fn get_class(&self) -> GString
pub fn get_class(&self) -> GString
Returns the object’s built-in class name, as a [String][crate::builtin::GString]. See also is_class.
Note: This method ignores class_name declarations. If this object’s script has defined a class_name, the base, built-in class name is returned instead.
Sourcepub fn is_class(&self, class: impl AsArg<GString>) -> bool
pub fn is_class(&self, class: impl AsArg<GString>) -> bool
Returns true if the object inherits from the given class. See also get_class.
var sprite2d = Sprite2D.new()
sprite2d.is_class("Sprite2D") # Returns true
sprite2d.is_class("Node") # Returns true
sprite2d.is_class("Node3D") # Returns falseNote: This method ignores class_name declarations in the object’s script.
Sourcepub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
pub fn set(&mut self, property: impl AsArg<StringName>, value: &Variant)
Assigns value to the given property. If the property does not exist or the given value’s type doesn’t match, nothing happens.
var node = Node2D.new()
node.set("global_scale", Vector2(8, 2.5))
print(node.global_scale) # Prints (8.0, 2.5)Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn get(&self, property: impl AsArg<StringName>) -> Variant
pub fn get(&self, property: impl AsArg<StringName>) -> Variant
Returns the [Variant][crate::builtin::Variant] value of the given property. If the property does not exist, this method returns null.
var node = Node2D.new()
node.rotation = 1.5
var a = node.get("rotation") # a is 1.5Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn set_indexed(
&mut self,
property_path: impl AsArg<NodePath>,
value: &Variant,
)
pub fn set_indexed( &mut self, property_path: impl AsArg<NodePath>, value: &Variant, )
Assigns a new value to the property identified by the property_path. The path should be a [NodePath][crate::builtin::NodePath] relative to this object, and can use the colon character (:) to access nested properties.
var node = Node2D.new()
node.set_indexed("position", Vector2(42, 0))
node.set_indexed("position:y", -10)
print(node.position) # Prints (42.0, -10.0)Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
pub fn get_indexed(&self, property_path: impl AsArg<NodePath>) -> Variant
Gets the object’s property indexed by the given property_path. The path should be a [NodePath][crate::builtin::NodePath] relative to the current object and can use the colon character (:) to access nested properties.
Examples: "position:x" or "material:next_pass:blend_mode".
var node = Node2D.new()
node.position = Vector2(5, -10)
var a = node.get_indexed("position") # a is Vector2(5, -10)
var b = node.get_indexed("position:y") # b is -10Note: In C#, property_path must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Note: This method does not support actual paths to nodes in the SceneTree, only sub-property paths. In the context of nodes, use get_node_and_resource instead.
Sourcepub fn get_property_list(&self) -> Array<VarDictionary>
pub fn get_property_list(&self) -> Array<VarDictionary>
Returns the object’s property list as an [Array][crate::builtin::Array] of dictionaries. Each [Dictionary][crate::builtin::Dictionary] contains the following entries:
-
nameis the property’s name, as a [String][crate::builtin::GString]; -
class_nameis an empty [StringName][crate::builtin::StringName], unless the property isVariantType::OBJECTand it inherits from a class; -
typeis the property’s type, as anint(see [enum Variant.Type]); -
hintis how the property is meant to be edited (see [enum PropertyHint]); -
hint_stringdepends on the hint (see [enum PropertyHint]); -
usageis a combination of [enum PropertyUsageFlags].
Note: In GDScript, all class members are treated as properties. In C# and GDExtension, it may be necessary to explicitly mark class members as Godot properties using decorators or attributes.
Sourcepub fn get_method_list(&self) -> Array<VarDictionary>
pub fn get_method_list(&self) -> Array<VarDictionary>
Returns this object’s methods and their signatures as an [Array][crate::builtin::Array] of dictionaries. Each [Dictionary][crate::builtin::Dictionary] contains the following entries:
-
nameis the name of the method, as a [String][crate::builtin::GString]; -
argsis an [Array][crate::builtin::Array] of dictionaries representing the arguments; -
default_argsis the default arguments as an [Array][crate::builtin::Array] of variants; -
flagsis a combination of [enum MethodFlags]; -
idis the method’s internal identifierint; -
returnis the returned value, as a [Dictionary][crate::builtin::Dictionary];
Note: The dictionaries of args and return are formatted identically to the results of get_property_list, although not all entries are used.
Sourcepub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
pub fn property_can_revert(&self, property: impl AsArg<StringName>) -> bool
Returns true if the given property has a custom default value. Use property_get_revert to get the property’s default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_can_revert] to customize the default value. If [method _property_can_revert] is not implemented, this method returns false.
Sourcepub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
pub fn property_get_revert(&self, property: impl AsArg<StringName>) -> Variant
Returns the custom default value of the given property. Use property_can_revert to check if the property has a custom default value.
Note: This method is used by the Inspector dock to display a revert icon. The object must implement [method _property_get_revert] to customize the default value. If [method _property_get_revert] is not implemented, this method returns null.
Sourcepub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
pub fn set_meta(&mut self, name: impl AsArg<StringName>, value: &Variant)
Adds or changes the entry name inside the object’s metadata. The metadata value can be any [Variant][crate::builtin::Variant], although some types cannot be serialized correctly.
If value is null, the entry is removed. This is the equivalent of using remove_meta. See also has_meta and get_meta.
Note: A metadata’s name must be a valid identifier as per [is_valid_identifier][crate::builtin::StringName::is_valid_identifier] method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
Sourcepub fn remove_meta(&mut self, name: impl AsArg<StringName>)
pub fn remove_meta(&mut self, name: impl AsArg<StringName>)
Removes the given entry name from the object’s metadata. See also has_meta, get_meta and set_meta.
Note: A metadata’s name must be a valid identifier as per [is_valid_identifier][crate::builtin::StringName::is_valid_identifier] method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
Sourcepub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
pub fn get_meta(&self, name: impl AsArg<StringName>) -> Variant
To set the default parameters, use get_meta_ex and its builder methods. See the book for detailed usage instructions.
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per [is_valid_identifier][crate::builtin::StringName::is_valid_identifier] method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
Sourcepub fn get_meta_ex<'ex>(
&'ex self,
name: impl AsArg<StringName> + 'ex,
) -> ExGetMeta<'ex>
pub fn get_meta_ex<'ex>( &'ex self, name: impl AsArg<StringName> + 'ex, ) -> ExGetMeta<'ex>
Returns the object’s metadata value for the given entry name. If the entry does not exist, returns default. If default is null, an error is also generated.
Note: A metadata’s name must be a valid identifier as per [is_valid_identifier][crate::builtin::StringName::is_valid_identifier] method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
Sourcepub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
pub fn has_meta(&self, name: impl AsArg<StringName>) -> bool
Returns true if a metadata entry is found with the given name. See also get_meta, set_meta and remove_meta.
Note: A metadata’s name must be a valid identifier as per [is_valid_identifier][crate::builtin::StringName::is_valid_identifier] method.
Note: Metadata that has a name starting with an underscore (_) is considered editor-only. Editor-only metadata is not displayed in the Inspector and should not be edited, although it can still be found by this method.
Sourcepub fn get_meta_list(&self) -> Array<StringName>
pub fn get_meta_list(&self) -> Array<StringName>
Returns the object’s metadata entry names as an [Array][crate::builtin::Array] of [StringName][crate::builtin::StringName]s.
Sourcepub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
pub fn add_user_signal(&mut self, signal: impl AsArg<GString>)
To set the default parameters, use add_user_signal_ex and its builder methods. See the book for detailed usage instructions.
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an [Array][crate::builtin::Array] of dictionaries, each defining a name [String][crate::builtin::GString] and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])Sourcepub fn add_user_signal_ex<'ex>(
&'ex mut self,
signal: impl AsArg<GString> + 'ex,
) -> ExAddUserSignal<'ex>
pub fn add_user_signal_ex<'ex>( &'ex mut self, signal: impl AsArg<GString> + 'ex, ) -> ExAddUserSignal<'ex>
Adds a user-defined signal named signal. Optional arguments for the signal can be added as an [Array][crate::builtin::Array] of dictionaries, each defining a name [String][crate::builtin::GString] and a type int (see [enum Variant.Type]). See also has_user_signal and remove_user_signal.
add_user_signal("hurt", [
{ "name": "damage", "type": TYPE_INT },
{ "name": "source", "type": TYPE_OBJECT }
])Sourcepub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_user_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given user-defined signal name exists. Only signals added with add_user_signal are included. See also remove_user_signal.
Sourcepub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
pub fn remove_user_signal(&mut self, signal: impl AsArg<StringName>)
Removes the given user signal signal from the object. See also add_user_signal and has_user_signal.
Sourcepub fn emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Error
pub fn emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Error
Emits the given signal by name. The signal must exist, so it should be a built-in signal of this class or one of its inherited classes, or a user-defined signal (see add_user_signal). This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
Returns Error::ERR_UNAVAILABLE if signal does not exist or the parameters are invalid.
emit_signal("hit", "sword", 100)
emit_signal("game_over")Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_emit_signal(
&mut self,
signal: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Error, CallError>
pub fn try_emit_signal( &mut self, signal: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Error, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object and returns the result. This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call("rotate", Vector3(1.0, 0.0, 0.0), 1.571)Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Variant
pub fn call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Variant
Calls the method on the object during idle time. Always returns null, not the method’s result.
Idle time happens mainly at the end of process and physics frames. In it, deferred calls will be run until there are none left, which means you can defer calls from other deferred calls and they’ll still be run in the current idle time cycle. This means you should not call a method deferred from itself (or from a method called by it), as this causes infinite recursion the same way as if you had called the method directly.
This method supports a variable number of arguments, so parameters can be passed as a comma separated list.
var node = Node3D.new()
node.call_deferred("rotate", Vector3(1.0, 0.0, 0.0), 1.571)For methods that are deferred from the same thread, the order of execution at idle time is identical to the order in which call_deferred was called.
See also [call_deferred][crate::builtin::Callable::call_deferred].
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Note: If you’re looking to delay the function call by a frame, refer to the SceneTree.process_frame and SceneTree.physics_frame signals.
var node = Node3D.new()
# Make a Callable and bind the arguments to the node's rotate() call.
var callable = node.rotate.bind(Vector3(1.0, 0.0, 0.0), 1.571)
# Connect the callable to the process_frame signal, so it gets called in the next process frame.
# CONNECT_ONE_SHOT makes sure it only gets called once instead of every frame.
get_tree().process_frame.connect(callable, CONNECT_ONE_SHOT)Panics
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will panic in such a case.
Sourcepub fn try_call_deferred(
&mut self,
method: impl AsArg<StringName>,
varargs: &[Variant],
) -> Result<Variant, CallError>
pub fn try_call_deferred( &mut self, method: impl AsArg<StringName>, varargs: &[Variant], ) -> Result<Variant, CallError>
Return type
This is a varcall method, meaning parameters and return values are passed as Variant.
It can detect call failures and will return Err in such a case.
Sourcepub fn set_deferred(
&mut self,
property: impl AsArg<StringName>,
value: &Variant,
)
pub fn set_deferred( &mut self, property: impl AsArg<StringName>, value: &Variant, )
Assigns value to the given property, at the end of the current frame. This is equivalent to calling set through call_deferred.
var node = Node2D.new()
add_child(node)
node.rotation = 1.5
node.set_deferred("rotation", 3.0)
print(node.rotation) # Prints 1.5
await get_tree().process_frame
print(node.rotation) # Prints 3.0Note: In C#, property must be in snake_case when referring to built-in Godot properties. Prefer using the names exposed in the PropertyName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn callv(
&mut self,
method: impl AsArg<StringName>,
arg_array: &AnyArray,
) -> Variant
pub fn callv( &mut self, method: impl AsArg<StringName>, arg_array: &AnyArray, ) -> Variant
Calls the method on the object and returns the result. Unlike call, this method expects all parameters to be contained inside arg_array.
var node = Node3D.new()
node.callv("rotate", [Vector3(1.0, 0.0, 0.0), 1.571])Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn has_method(&self, method: impl AsArg<StringName>) -> bool
pub fn has_method(&self, method: impl AsArg<StringName>) -> bool
Returns true if the given method name exists in the object.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
pub fn get_method_argument_count(&self, method: impl AsArg<StringName>) -> i32
Returns the number of arguments of the given method by name.
Note: In C#, method must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the MethodName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_signal(&self, signal: impl AsArg<StringName>) -> bool
Returns true if the given signal name exists in the object.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn get_signal_list(&self) -> Array<VarDictionary>
pub fn get_signal_list(&self) -> Array<VarDictionary>
Returns the list of existing signals as an [Array][crate::builtin::Array] of dictionaries.
Note: Due to the implementation, each [Dictionary][crate::builtin::Dictionary] is formatted very similarly to the returned values of get_method_list.
Sourcepub fn get_signal_connection_list(
&self,
signal: impl AsArg<StringName>,
) -> Array<VarDictionary>
pub fn get_signal_connection_list( &self, signal: impl AsArg<StringName>, ) -> Array<VarDictionary>
Returns an [Array][crate::builtin::Array] of connections for the given signal name. Each connection is represented as a [Dictionary][crate::builtin::Dictionary] that contains three entries:
-
signalis a reference to the [Signal][crate::builtin::Signal]; -
callableis a reference to the connected [Callable][crate::builtin::Callable]; -
flagsis a combination of [enum ConnectFlags].
Sourcepub fn get_incoming_connections(&self) -> Array<VarDictionary>
pub fn get_incoming_connections(&self) -> Array<VarDictionary>
Returns an [Array][crate::builtin::Array] of signal connections received by this object. Each connection is represented as a [Dictionary][crate::builtin::Dictionary] that contains three entries:
-
signalis a reference to the [Signal][crate::builtin::Signal]; -
callableis a reference to the [Callable][crate::builtin::Callable]; -
flagsis a combination of [enum ConnectFlags].
Sourcepub fn disconnect(
&mut self,
signal: impl AsArg<StringName>,
callable: &Callable,
)
pub fn disconnect( &mut self, signal: impl AsArg<StringName>, callable: &Callable, )
Disconnects a signal by name from a given callable. If the connection does not exist, generates an error. Use is_connected to make sure that the connection exists.
Sourcepub fn is_connected(
&self,
signal: impl AsArg<StringName>,
callable: &Callable,
) -> bool
pub fn is_connected( &self, signal: impl AsArg<StringName>, callable: &Callable, ) -> bool
Returns true if a connection exists between the given signal name and callable.
Note: In C#, signal must be in snake_case when referring to built-in Godot signals. Prefer using the names exposed in the SignalName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
pub fn has_connections(&self, signal: impl AsArg<StringName>) -> bool
Returns true if any connection exists on the given signal name.
Note: In C#, signal must be in snake_case when referring to built-in Godot methods. Prefer using the names exposed in the SignalName class to avoid allocating a new [StringName][crate::builtin::StringName] on each call.
Sourcepub fn set_block_signals(&mut self, enable: bool)
pub fn set_block_signals(&mut self, enable: bool)
If set to true, the object becomes unable to emit signals. As such, emit_signal and signal connections will not work, until it is set to false.
Sourcepub fn is_blocking_signals(&self) -> bool
pub fn is_blocking_signals(&self) -> bool
Returns true if the object is blocking its signals from being emitted. See set_block_signals.
Sourcepub fn notify_property_list_changed(&mut self)
pub fn notify_property_list_changed(&mut self)
Emits the property_list_changed signal. This is mainly used to refresh the editor, so that the Inspector and editor plugins are properly updated.
Sourcepub fn set_message_translation(&mut self, enable: bool)
pub fn set_message_translation(&mut self, enable: bool)
If set to true, allows the object to translate messages with tr and tr_n. Enabled by default. See also can_translate_messages.
Sourcepub fn can_translate_messages(&self) -> bool
pub fn can_translate_messages(&self) -> bool
Returns true if the object is allowed to translate messages with tr and tr_n. See also set_message_translation.
Sourcepub fn tr(&self, message: impl AsArg<StringName>) -> GString
pub fn tr(&self, message: impl AsArg<StringName>) -> GString
To set the default parameters, use tr_ex and its builder methods. See the book for detailed usage instructions.
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use [method TranslationServer.translate].
Sourcepub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
pub fn tr_ex<'ex>(&'ex self, message: impl AsArg<StringName> + 'ex) -> ExTr<'ex>
Translates a message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation. Note that most Control nodes automatically translate their strings, so this method is mostly useful for formatted strings or custom drawn text.
If can_translate_messages is false, or no translation is available, this method returns the message without changes. See set_message_translation.
For detailed examples, see Internationalizing games.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use [method TranslationServer.translate].
Sourcepub fn tr_n(
&self,
message: impl AsArg<StringName>,
plural_message: impl AsArg<StringName>,
n: i32,
) -> GString
pub fn tr_n( &self, message: impl AsArg<StringName>, plural_message: impl AsArg<StringName>, n: i32, ) -> GString
To set the default parameters, use tr_n_ex and its builder methods. See the book for detailed usage instructions.
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use [method TranslationServer.translate_plural].
Sourcepub fn tr_n_ex<'ex>(
&'ex self,
message: impl AsArg<StringName> + 'ex,
plural_message: impl AsArg<StringName> + 'ex,
n: i32,
) -> ExTrN<'ex>
pub fn tr_n_ex<'ex>( &'ex self, message: impl AsArg<StringName> + 'ex, plural_message: impl AsArg<StringName> + 'ex, n: i32, ) -> ExTrN<'ex>
Translates a message or plural_message, using the translation catalogs configured in the Project Settings. Further context can be specified to help with the translation.
If can_translate_messages is false, or no translation is available, this method returns message or plural_message, without changes. See set_message_translation.
The n is the number, or amount, of the message’s subject. It is used by the translation system to fetch the correct plural form for the current language.
For detailed examples, see Localization using gettext.
Note: Negative and float numbers may not properly apply to some countable subjects. It’s recommended to handle these cases with tr.
Note: This method can’t be used without an Object instance, as it requires the can_translate_messages method. To translate strings in a static context, use [method TranslationServer.translate_plural].
Sourcepub fn get_translation_domain(&self) -> StringName
pub fn get_translation_domain(&self) -> StringName
Sourcepub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
pub fn set_translation_domain(&mut self, domain: impl AsArg<StringName>)
Sourcepub fn is_queued_for_deletion(&self) -> bool
pub fn is_queued_for_deletion(&self) -> bool
Returns true if the queue_free method was called for the object.
Sourcepub fn cancel_free(&mut self)
pub fn cancel_free(&mut self)
If this method is called during ObjectNotification::PREDELETE, this object will reject being freed and will remain allocated. This is mostly an internal function used for error handling to avoid the user from freeing objects when they are not intended to.
Sourcepub fn notify(&mut self, what: ObjectNotification)
pub fn notify(&mut self, what: ObjectNotification)
⚠️ Sends a Godot notification to all classes inherited by the object.
Triggers calls to on_notification(), and depending on the notification, also to Godot’s lifecycle callbacks such as ready().
Starts from the highest ancestor (the Object class) and goes down the hierarchy.
See also Godot docs for Object::notification().
Panics
If you call this method on a user-defined object while holding a GdRef or GdMut guard on the instance, you will encounter
a panic. The reason is that the receiving virtual method on_notification() acquires a GdMut lock dynamically, which must
be exclusive.
Sourcepub fn notify_reversed(&mut self, what: ObjectNotification)
pub fn notify_reversed(&mut self, what: ObjectNotification)
⚠️ Like Self::notify(), but starts at the most-derived class and goes up the hierarchy.
See docs of that method, including the panics.